@@ -8,35 +8,34 @@ App::CLI::Extension::Component::Stash - for App::CLI::Extension stash module
 
 =head1 VERSION
 
-0.7
+1.0
 
 =cut
 
 use strict;
 use base qw(Class::Data::Accessor);
 
-our $VERSION  = '0.7';
+our $VERSION  = '1.0';
 
 __PACKAGE__->mk_classaccessor( _stash => {} );
 
 sub stash {
 
-    my $self = shift;
+	my $self = shift;
 
-    my %hash;
-    if(scalar(@_) == 1 && ref($_[0]) eq "HASH"){
-        %hash = %{$_[0]}
-    } elsif(scalar(@_) > 1) {
-        %hash = @_;
-    }
-    my @keys = keys %hash;
-    if (scalar(@keys) > 0) {
-        map { $self->_stash->{$_} = $hash{$_} } @keys;
-    }
-    return $self->_stash;
+	my %hash;
+	if(scalar(@_) == 1 && ref($_[0]) eq "HASH"){
+		%hash = %{$_[0]};
+	} elsif (scalar(@_) > 1) {
+		%hash = @_;
+	}
+	my @keys = keys %hash;
+	if (scalar(@keys) > 0) {
+		map { $self->_stash->{$_} = $hash{$_} } @keys;
+	}
+	return $self->_stash;
 }
 
-
 1;
 
 __END__
